@@ -1,11 +1,14 @@
 #!/bin/sh
 
+set -x
+
 if [ "x$TRAVIS_OS_NAME" != "xosx" ]; then
     sudo apt-get update -qq || true
     sudo apt-get remove -qq -y $REMOVE
     sudo apt-get autoremove -qq
     sudo apt-get install -qq -y --no-install-recommends libyubikey-dev asciidoc docbook-xsl xsltproc libxml2-utils $EXTRA
 else
+    brew update
     brew uninstall libtool
     brew install libtool
     brew install libyubikey
