@@ -49,7 +49,7 @@ int _ykusb_stop(void)
 	return 1;
 }
 
-void * _ykusb_open_device(int vendor_id, int *product_ids, size_t pids_len, int index)
+void * _ykusb_open_device(int vendor_id, const int *product_ids, size_t pids_len, int index)
 {
 	HDEVINFO hi;
 	SP_DEVICE_INTERFACE_DATA di;
