@@ -48,10 +48,12 @@ int main(int argc, char **argv)
 	FILE *outf = NULL; const char *outfname = NULL;
 	int data_format = YKP_FORMAT_LEGACY;
 	bool verbose = false;
-	char keylocation = 0;
-	bool use_access_code = false;
 	unsigned char access_code[256];
+	char *acc_code = NULL;
+	char *new_acc_code = NULL;
 	unsigned char scan_codes[sizeof(SCAN_MAP)];
+	unsigned char device_info[128];
+	size_t device_info_len = 0;
 	YK_KEY *yk = 0;
 	YKP_CONFIG *cfg = ykp_alloc();
 	YK_STATUS *st = ykds_alloc();
@@ -96,6 +98,8 @@ int main(int argc, char **argv)
 						continue;
 					case 'a':
 						continue;
+					case 'c':
+						continue;
 				}
 				fprintf(stderr, "Option %c requires an argument.\n", optopt);
 				exit(1);
@@ -145,14 +149,15 @@ int main(int argc, char **argv)
 	}
 
 	/* Parse all arguments in a testable way */
-	if (! args_to_config(argc, argv, cfg, oathid,
+	if (! args_to_config(argc, argv, cfg, oathid, sizeof(oathid),
 			     &infname, &outfname,
 			     &data_format, &autocommit,
 			     st, &verbose, &dry_run,
-			     access_code, &use_access_code,
-			     &keylocation, &ndef_type, ndef_string,
+			     &acc_code, &new_acc_code,
+			     &ndef_type, ndef_string, sizeof(ndef_string),
 			     &usb_mode, &zap, scan_codes, &cr_timeout,
-			     &autoeject_timeout, &num_modes_seen, &exit_code)) {
+			     &autoeject_timeout, &num_modes_seen,
+					 device_info, &device_info_len, &exit_code)) {
 		goto err;
 	}
 
@@ -160,6 +165,40 @@ int main(int argc, char **argv)
 		set_oath_id(oathid, cfg, yk, st);
 	}
 
+	if (acc_code) {
+		size_t access_code_len = 0;
+		int rc = hex_modhex_decode(access_code, &access_code_len,
+				acc_code, strlen(acc_code),
+				12, 12, false);
+		if (rc <= 0) {
+			fprintf(stderr,
+					"Invalid access code string: %s\n",
+					optarg);
+			exit_code = 1;
+			goto err;
+		}
+		if (!new_acc_code) {
+			ykp_set_access_code(cfg,
+					access_code,
+					access_code_len);
+		}
+	}
+	if(new_acc_code) {
+		unsigned char accbin[256];
+		size_t accbinlen = 0;
+		int rc = hex_modhex_decode (accbin, &accbinlen,
+				new_acc_code, strlen(new_acc_code),
+				12, 12, false);
+		if (rc <= 0) {
+			fprintf(stderr,
+					"Invalid access code string: %s\n",
+					new_acc_code);
+			exit_code = 1;
+			goto err;
+		}
+		ykp_set_access_code(cfg, accbin, accbinlen);
+	}
+
 	if (verbose && (ykds_version_major(st) > 2 ||
 			(ykds_version_major(st) == 2 &&
 			 ykds_version_minor(st) >= 2) ||
@@ -214,77 +253,6 @@ int main(int argc, char **argv)
 		if (!ykp_import_config(cfg, data, strlen(data), data_format))
 			goto err;
 	}
-	if (! zap && (ykp_command(cfg) == SLOT_CONFIG || ykp_command(cfg) == SLOT_CONFIG2)) {
-		int key_bytes = ykp_get_supported_key_length(cfg);
-		char keybuf[42];
-		size_t keylen;
-		if(keylocation == 2) {
-			if(key_bytes == 20) {
-				fprintf(stderr, " HMAC key, 20 bytes (40 characters hex) : ");
-			} else {
-				fprintf(stderr, " AES key, 16 bytes (32 characters hex) : ");
-			}
-			fflush(stderr);
-			if(!fgets(keybuf, sizeof(keybuf), stdin)) {
-				printf("error?\n");
-				perror ("fgets");
-				exit_code = 1;
-				goto err;
-			}
-			keylen = strnlen(keybuf, sizeof(keybuf));
-			if(keybuf[keylen - 1] == '\n') {
-				keybuf[keylen - 1] = '\0';
-			}
-			if(key_bytes == 20) {
-				if(ykp_HMAC_key_from_hex(cfg, keybuf)) {
-					goto err;
-				}
-			} else {
-				if(ykp_AES_key_from_hex(cfg, keybuf)) {
-					goto err;
-				}
-			}
-		} else if(keylocation == 0) {
-			const char *random_places[] = {
-				"/dev/srandom",
-				"/dev/urandom",
-				"/dev/random",
-				0
-			};
-			const char **random_place;
-			size_t read_bytes = 0;
-
-			for (random_place = random_places; *random_place; random_place++) {
-				FILE *random_file = fopen(*random_place, "r");
-				if (random_file) {
-					read_bytes = 0;
-
-					while (read_bytes < key_bytes) {
-						size_t n = fread(&keybuf[read_bytes], 1,
-								key_bytes - read_bytes, random_file);
-						read_bytes += n;
-					}
-
-					fclose(random_file);
-					break;
-				}
-			}
-			if(read_bytes < key_bytes) {
-				ykp_errno = YKP_ENORANDOM;
-				goto err;
-			}
-			if(key_bytes == 20) {
-				if(ykp_HMAC_key_from_raw(cfg, keybuf)) {
-					goto err;
-				}
-			} else {
-				if(ykp_AES_key_from_raw(cfg, keybuf)) {
-					goto err;
-				}
-			}
-		}
-	}
-
 	if (outf) {
 		if(!(ykp_export_config(cfg, data, 1024, data_format))) {
 			goto err;
@@ -309,6 +277,8 @@ int main(int argc, char **argv)
 			}
 		} else if(ykp_command(cfg) == SLOT_SCAN_MAP) {
 			fprintf(stderr, "A new scanmap will be written.\n");
+		} else if(ykp_command(cfg) == SLOT_YK4_SET_DEVICE_INFO) {
+			fprintf(stderr, "New device information will be written.\n");
 		} else if(zap) {
 			fprintf(stderr, "Configuration in slot %d will be deleted\n", ykp_config_num(cfg));
 		} else {
@@ -332,7 +302,7 @@ int main(int argc, char **argv)
 			}
 		}
 		commitlen = strlen(commitbuf);
-		if (commitbuf[commitlen - 1] == '\n')
+		if (commitlen > 0 && commitbuf[commitlen - 1] == '\n')
 			commitbuf[commitlen - 1] = '\0';
 		if (strcmp(commitbuf, "y") == 0
 		    || strcmp(commitbuf, "yes") == 0) {
@@ -358,7 +328,7 @@ int main(int argc, char **argv)
 					}
 					goto err;
 				}
-				if(use_access_code) {
+				if(acc_code) {
 					if(!ykp_set_ndef_access_code(ndef, access_code)) {
 						if(verbose) {
 							printf(" failure to set ndef accesscode\n");
@@ -399,7 +369,7 @@ int main(int argc, char **argv)
 						}
 					}
 					commitlen = strlen(commitbuf);
-					if (commitbuf[commitlen - 1] == '\n')
+					if (commitlen > 0 && commitbuf[commitlen - 1] == '\n')
 						commitbuf[commitlen - 1] = '\0';
 					if (strcmp(commitbuf, "y") != 0
 							&& strcmp(commitbuf, "yes") != 0) {
@@ -423,6 +393,12 @@ int main(int argc, char **argv)
 						printf(" failure\n");
 					goto err;
 				}
+			} else if(ykp_command(cfg) == SLOT_YK4_SET_DEVICE_INFO) {
+				if(!yk_write_device_info(yk, device_info, device_info_len)) {
+					if(verbose)
+						printf(" failure\n");
+					goto err;
+				}
 			} else {
 				YK_CONFIG *ycfg = NULL;
 				/* if we're deleting a slot we send the configuration as NULL */
@@ -431,7 +407,7 @@ int main(int argc, char **argv)
 				}
 				if (!yk_write_command(yk,
 							ycfg, ykp_command(cfg),
-							use_access_code ? access_code : NULL)) {
+							acc_code ? access_code : NULL)) {
 					if (verbose)
 						printf(" failure\n");
 					goto err;
@@ -471,5 +447,8 @@ err:
 	if (cfg)
 		ykp_free_config(cfg);
 
+	free(acc_code);
+	free(new_acc_code);
+
 	exit(exit_code);
 }
